@@ -1,5 +1,5 @@
 package DBIx::Lite::ResultSet;
-$DBIx::Lite::ResultSet::VERSION = '0.24';
+$DBIx::Lite::ResultSet::VERSION = '0.25';
 use strict;
 use warnings;
 
@@ -542,8 +542,8 @@ sub _table_alias {
     
     if ($table_name eq $self->{table}{name}) {
         if ($op eq 'select'
-            || ($op eq 'update' && $driver_name =~ /^(?:MySQL|Pg)$/)
-            || ($op eq 'delete' && $driver_name eq 'Pg')) {
+            || ($op eq 'update' && $driver_name =~ /^(?:MySQL|Pg)$/i)
+            || ($op eq 'delete' && $driver_name =~ /^Pg$/i)) {
             return 'me';
         }
     }
@@ -643,7 +643,7 @@ DBIx::Lite::ResultSet
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 OVERVIEW
 
