@@ -1,5 +1,5 @@
 package DBIx::Lite::Schema::Table;
-$DBIx::Lite::Schema::Table::VERSION = '0.24';
+$DBIx::Lite::Schema::Table::VERSION = '0.25';
 use strict;
 use warnings;
 
@@ -76,7 +76,14 @@ sub class {
     if ($storage) {
         no strict 'refs';
         no warnings 'redefine';
-        *{ "${class}::__dbix_lite_row_storage" } = sub { $_[0]->$storage };
+        *{ "${class}::__dbix_lite_row_storage" } = sub {
+            my ($row) = @_;
+            
+            croak "$class does not provide a $storage method"
+                if !$row->can($storage);
+            
+            return $row->$storage;
+        };
     }
     
     return $class;
@@ -117,7 +124,7 @@ DBIx::Lite::Schema::Table
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 OVERVIEW
 
